# Generated by Django 5.2.6 on 2026-01-09 16:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0020_alter_rule_value'),
    ]

    operations = [
        migrations.AlterField(
            model_name='incident',
            name='id',
            field=models.BigAutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='event',
            name='incident',
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name='events',
                to='incident.incident',
            ),
        ),
        migrations.AlterField(
            model_name='event',
            name='id',
            field=models.BigAutoField(primary_key=True, serialize=False),
        ),
    ]
