# Generated by Django 4.2.21 on 2025-08-27 21:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aws', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='emaildomain',
            name='can_recv',
            field=models.BooleanField(default=False, help_text='True if inbound receiving is ready per last audit'),
        ),
        migrations.AddField(
            model_name='emaildomain',
            name='can_send',
            field=models.BooleanField(default=False, help_text='True if outbound sending is ready per last audit'),
        ),
        migrations.AlterField(
            model_name='emaildomain',
            name='status',
            field=models.CharField(db_index=True, default='pending', help_text='Domain status: "pending" (created), "ready" (audit passed), or "missing" (audit failed)', max_length=32),
        ),
    ]
