# Generated by Django 5.2.6 on 2025-12-01 22:06

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0025_remove_passkeychallenge_user_and_more'),
        ('fileman', '0011_alter_filerendition_original_file'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name='filemanager',
            name='fileman_fil_group_i_c1c47d_idx',
        ),
        migrations.AddField(
            model_name='filemanager',
            name='use',
            field=models.CharField(blank=True, db_index=True, default='', help_text="Optional purpose key (e.g., 'invoices') to support multiple managers per group", max_length=64),
        ),
        migrations.AddIndex(
            model_name='filemanager',
            index=models.Index(fields=['group', 'use', 'is_default'], name='fileman_fil_group_i_b30586_idx'),
        ),
        migrations.AddIndex(
            model_name='filemanager',
            index=models.Index(fields=['group', 'use', 'backend_type'], name='fileman_fil_group_i_9b9e62_idx'),
        ),
    ]
