# Generated by Django 4.2.21 on 2025-05-31 23:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('logit', '0002_log_duid_log_payload_log_username'),
    ]

    operations = [
        migrations.AddField(
            model_name='log',
            name='level',
            field=models.CharField(db_index=True, default='low', max_length=12),
        ),
    ]
