# Generated by Django 4.2.25 on 2025-10-22 02:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0020_remove_pushconfig_apns_bundle_id_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pushconfig',
            name='fcm_sender_id',
        ),
    ]
