# Generated by Django 4.2.21 on 2025-05-31 23:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('logit', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='log',
            name='duid',
            field=models.TextField(default=None, null=True),
        ),
        migrations.AddField(
            model_name='log',
            name='payload',
            field=models.TextField(default=None, null=True),
        ),
        migrations.AddField(
            model_name='log',
            name='username',
            field=models.TextField(default=None, null=True),
        ),
    ]
