# Generated by Django 4.2.21 on 2025-06-04 13:42

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='ruleset',
            old_name='bundle',
            new_name='bundle_minutes',
        ),
        migrations.AddField(
            model_name='event',
            name='hostname',
            field=models.CharField(db_index=True, default=None, max_length=16, null=True),
        ),
        migrations.AddField(
            model_name='event',
            name='source_ip',
            field=models.CharField(db_index=True, default=None, max_length=16, null=True),
        ),
        migrations.AddField(
            model_name='incident',
            name='hostname',
            field=models.CharField(db_index=True, default=None, max_length=16, null=True),
        ),
        migrations.AddField(
            model_name='incident',
            name='rule_set',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='incidents', to='incident.ruleset'),
        ),
        migrations.AlterField(
            model_name='incident',
            name='source_ip',
            field=models.CharField(db_index=True, default=None, max_length=16, null=True),
        ),
    ]
