# Generated by Django 4.2.24 on 2026-03-17 19:29

from django.db import migrations, models
import django.db.models.deletion
import mojo.models.rest


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0034_userapikey'),
    ]

    operations = [
        migrations.CreateModel(
            name='Setting',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('mojo_secrets', models.TextField(blank=True, default=None, null=True)),
                ('created', models.DateTimeField(auto_now_add=True, db_index=True)),
                ('modified', models.DateTimeField(auto_now=True, db_index=True)),
                ('key', models.CharField(db_index=True, max_length=255)),
                ('value', models.TextField(blank=True, default='')),
                ('is_secret', models.BooleanField(db_index=True, default=False)),
                ('group', models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='settings', to='account.group')),
            ],
            options={
                'ordering': ['key'],
                'unique_together': {('key', 'group')},
            },
            bases=(models.Model, mojo.models.rest.MojoModel),
        ),
    ]
