# Generated by Django 5.2.7 on 2026-02-24 17:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0027_apikey_metadata'),
    ]

    operations = [
        migrations.AddField(
            model_name='geolocatedip',
            name='blocked_at',
            field=models.DateTimeField(blank=True, help_text='When this IP was blocked', null=True),
        ),
        migrations.AddField(
            model_name='geolocatedip',
            name='blocked_reason',
            field=models.CharField(blank=True, help_text='auto or manual', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='geolocatedip',
            name='is_blocked',
            field=models.BooleanField(db_index=True, default=False, help_text='Is this IP blocked?'),
        ),
        migrations.AddIndex(
            model_name='geolocatedip',
            index=models.Index(fields=['is_blocked', 'threat_level'], name='account_geo_is_bloc_e89dd5_idx'),
        ),
    ]
