# Generated by Django 5.2.6 on 2025-10-16 19:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0017_geolocatedip_last_seen'),
    ]

    operations = [
        migrations.AddField(
            model_name='geolocatedip',
            name='is_known_abuser',
            field=models.BooleanField(db_index=True, default=False, help_text='Is this IP from a datacenter/hosting provider?'),
        ),
        migrations.AddField(
            model_name='geolocatedip',
            name='is_known_attacker',
            field=models.BooleanField(db_index=True, default=False, help_text='Is this IP from a datacenter/hosting provider?'),
        ),
    ]
