# Generated by Django 4.2.21 on 2025-06-08 16:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fileman', '0006_file_download_url_filemanager_forever_urls'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='filemanager',
            name='forever_urls',
        ),
        migrations.AddField(
            model_name='filemanager',
            name='is_public',
            field=models.BooleanField(default=True, help_text='Whether this allows public access to the files'),
        ),
    ]
