# Generated by Django 5.2.6 on 2025-10-22 00:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0019_alter_userdevicelocation_user'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pushconfig',
            name='apns_bundle_id',
        ),
        migrations.RemoveField(
            model_name='pushconfig',
            name='apns_enabled',
        ),
        migrations.RemoveField(
            model_name='pushconfig',
            name='apns_key_id',
        ),
        migrations.RemoveField(
            model_name='pushconfig',
            name='apns_team_id',
        ),
        migrations.RemoveField(
            model_name='pushconfig',
            name='apns_use_sandbox',
        ),
        migrations.RemoveField(
            model_name='pushconfig',
            name='default_badge_count',
        ),
        migrations.RemoveField(
            model_name='pushconfig',
            name='fcm_enabled',
        ),
    ]
