# Generated by Django 5.2.7 on 2026-03-11 21:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0029_usertotp_oauthconnection'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='phone_number',
            field=models.CharField(blank=True, default=None, max_length=32, null=True, unique=True),
        ),
    ]
