# Generated by Django 4.2.21 on 2025-06-08 12:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fileman', '0004_remove_file_original_filename_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='file',
            name='upload_token',
            field=models.CharField(db_index=True, help_text='Unique token for tracking direct uploads', max_length=64),
        ),
    ]
