# Generated by Django 5.2.6 on 2025-10-21 17:26

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0018_geolocatedip_is_known_abuser_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userdevicelocation',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='locations', to=settings.AUTH_USER_MODEL),
        ),
    ]
