# Generated by Django 4.2.21 on 2025-08-30 19:06

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('docit', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='book',
            name='modified_by',
            field=models.ForeignKey(default=None, help_text='User who last modified this book', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='modified_books', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='page',
            name='modified_by',
            field=models.ForeignKey(default=None, help_text='User who last modified this page', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='modified_pages', to=settings.AUTH_USER_MODEL),
        ),
    ]
