# Generated by Django 5.2.6 on 2025-10-01 01:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0014_notificationdelivery_data_payload_and_more'),
        ('incident', '0015_alter_ticket_options'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticketnote',
            name='group',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='account.group'),
        ),
    ]
