# Generated by Django 4.2.21 on 2025-06-08 04:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('fileman', '0002_filemanager_parent_alter_filemanager_max_file_size'),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name='file',
            name='fileman_fil_upload__c4bc35_idx',
        ),
        migrations.RemoveField(
            model_name='file',
            name='upload_expires_at',
        ),
        migrations.RemoveField(
            model_name='file',
            name='upload_url',
        ),
    ]
