# Generated by Django 5.2.7 on 2025-11-14 02:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0024_passkey_passkeychallenge'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='passkeychallenge',
            name='user',
        ),
        migrations.RemoveField(
            model_name='passkey',
            name='attestation_format',
        ),
        migrations.AlterField(
            model_name='passkey',
            name='rp_id',
            field=models.CharField(db_index=True, help_text='Relying Party ID (hostname of the portal)', max_length=255),
        ),
        migrations.AlterField(
            model_name='passkey',
            name='token',
            field=models.TextField(help_text='Base64url encoded AttestedCredentialData payload'),
        ),
        migrations.AddIndex(
            model_name='passkey',
            index=models.Index(fields=['user', 'rp_id', 'is_enabled'], name='account_pas_user_id_b38bb2_idx'),
        ),
        migrations.DeleteModel(
            name='PasskeyChallenge',
        ),
    ]
