# Generated by Django 4.2.23 on 2025-09-06 00:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aws', '0004_s3bucket'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emaildomain',
            name='region',
            field=models.CharField(default='us-east-1', help_text='AWS region for SES operations', max_length=64),
        ),
        migrations.DeleteModel(
            name='S3Bucket',
        ),
    ]
