# Generated by Django 4.2.21 on 2025-08-30 03:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0011_user_org_registereddevice_pushconfig_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pushconfig',
            name='apns_key_file',
        ),
        migrations.RemoveField(
            model_name='pushconfig',
            name='fcm_server_key',
        ),
    ]
