# Generated by Django 4.2.23 on 2025-09-06 00:00

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import mojo.models.rest


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('account', '0014_notificationdelivery_data_payload_and_more'),
        ('aws', '0003_mailbox_is_domain_default_mailbox_is_system_default_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='S3Bucket',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('mojo_secrets', models.TextField(blank=True, default=None, null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True, db_index=True)),
                ('name', models.CharField(db_index=True, max_length=255, unique=True)),
                ('region', models.CharField(default='us-west-2', help_text='AWS region for SES operations', max_length=64)),
                ('metadata', models.JSONField(blank=True, default=dict)),
                ('is_active', models.BooleanField(db_index=True, default=False)),
                ('is_system_default', models.BooleanField(db_index=True, default=False)),
                ('is_group_default', models.BooleanField(db_index=True, default=False)),
                ('group', models.ForeignKey(default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='s3_buckets', to='account.group')),
                ('user', models.ForeignKey(default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='s3_buckets', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model, mojo.models.rest.MojoModel),
        ),
    ]
