# Generated by Django 4.2.21 on 2025-08-26 16:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('logit', '0003_log_level'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='level',
            field=models.CharField(db_index=True, default='info', max_length=12),
        ),
    ]
