# Generated by Django 5.2.6 on 2025-09-23 04:24

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0012_alter_incident_status'),
    ]

    operations = [
        migrations.RenameField(
            model_name='ticketnote',
            old_name='author',
            new_name='user',
        ),
    ]
