# Generated by Django 4.2.21 on 2025-06-09 05:37

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('fileman', '0010_filerendition'),
    ]

    operations = [
        migrations.AlterField(
            model_name='filerendition',
            name='original_file',
            field=models.ForeignKey(help_text='The parent file', on_delete=django.db.models.deletion.CASCADE, related_name='file_renditions', to='fileman.file'),
        ),
    ]
