# Generated by Django 5.2.7 on 2025-10-24 04:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0022_geolocatedip_is_mobile_mobile_carrier'),
    ]

    operations = [
        migrations.RenameIndex(
            model_name='geolocatedip',
            new_name='account_geo_is_mobi_06bfa8_idx',
            old_name='account_geo_is_mobi_8a7c2e_idx',
        ),
        migrations.AlterField(
            model_name='geolocatedip',
            name='is_known_abuser',
            field=models.BooleanField(db_index=True, default=False, help_text='Is this IP a known abuser?'),
        ),
        migrations.AlterField(
            model_name='geolocatedip',
            name='is_known_attacker',
            field=models.BooleanField(db_index=True, default=False, help_text='Is this IP a known attacker?'),
        ),
    ]
